# Gowin Boards

The {py:mod}`torii.platform.vendor.gowin` module provides a base platform to support [Gowin] devices with the [Apicula] and the vendor toolchains.


```{eval-rst}

.. automodule:: torii_boards.gowin.tang_nano
	:members:
	:undoc-members:


```

[Apicula]: https://github.com/YosysHQ/apicula
[Gowin]: https://www.gowinsemi.com/en/support/home/
